@@ -1,4 +1,7 @@
 """Core Curate App Settings
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
 """
 import os
 
@@ -23,3 +26,7 @@ CURATE_MENU_NAME = getattr(settings, "CURATE_MENU_NAME", "Curator")
 
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 LOCALE_PATHS = (os.path.join(BASE_DIR, "core_curate_app/locale"),)
+
+ENABLE_XML_ENTITIES_TOOLTIPS = getattr(settings, "ENABLE_XML_ENTITIES_TOOLTIPS", True)
+""" boolean: enable the xml entities warning tooltip on the GUI.
+"""
