@@ -90,7 +90,9 @@ def generate_choice(request, curate_data_structure_id):
         template = template_api.get(
             str(curate_data_structure.template.id), request=request
         )
-        html_form = xsd_parser.generate_choice_absent(element_id, template.content)
+        html_form = xsd_parser.generate_choice_absent(
+            element_id, template.content, data_structure=curate_data_structure
+        )
     except Exception as e:
         return HttpResponseBadRequest(escape(str(e)))
 
@@ -121,7 +123,9 @@ def generate_element(request, curate_data_structure_id):
         template = template_api.get(
             str(curate_data_structure.template.id), request=request
         )
-        html_form = xsd_parser.generate_element_absent(element_id, template.content)
+        html_form = xsd_parser.generate_element_absent(
+            element_id, template.content, data_structure=curate_data_structure
+        )
     except Exception as e:
         return HttpResponseBadRequest(escape(str(e)))
 
@@ -206,7 +210,9 @@ def clear_fields(request):
         template = template_api.get(
             str(curate_data_structure.template.id), request=request
         )
-        root_element = generate_form(template.content, request=request)
+        root_element = generate_form(
+            template.content, data_structure=curate_data_structure, request=request
+        )
 
         # save the root element in the data structure
         curate_data_structure_api.update_data_structure_root(
@@ -258,7 +264,12 @@ def cancel_changes(request):
         template = template_api.get(
             str(curate_data_structure.template.id), request=request
         )
-        root_element = generate_form(template.content, xml_data, request=request)
+        root_element = generate_form(
+            template.content,
+            xml_data,
+            data_structure=curate_data_structure,
+            request=request,
+        )
 
         # save the root element in the data structure
         curate_data_structure_api.update_data_structure_root(
